<!DOCTYPE html>
<html>
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Reply to Your Comment</title>
</head>
<body style="font-family: Arial, sans-serif; line-height: 1.6; color: #333; margin: 0; padding: 0; background-color: #f4f4f4;">
    <div style="max-width: 600px; margin: 20px auto; background-color: #ffffff; border-radius: 8px; overflow: hidden; box-shadow: 0 2px 4px rgba(0,0,0,0.1);">
        <!-- Header -->
        <div style="background: linear-gradient(135deg, #11998e 0%, #38ef7d 100%); padding: 30px 20px; text-align: center;">
            <h1 style="color: #ffffff; margin: 0; font-size: 24px; font-weight: 600;">
                💬 {{ comment.get_user_name }} replied to your comment
            </h1>
        </div>
        
        <!-- Content -->
        <div style="padding: 30px 20px;">
            <p style="font-size: 16px; margin-bottom: 20px;">
                Someone replied to your comment on: <strong>{{ content_object }}</strong>
            </p>
            
            <!-- Your Comment -->
            <div style="background: #e8f5e9; padding: 15px; border-left: 4px solid #4caf50; border-radius: 4px; margin: 20px 0;">
                <p style="margin: 0 0 8px 0; font-size: 12px; font-weight: 600; color: #2e7d32; text-transform: uppercase; letter-spacing: 0.5px;">
                    Your Comment
                </p>
                <p style="margin: 0; color: #555; white-space: pre-wrap;">{{ parent_comment.content }}</p>
            </div>
            
            <!-- Their Reply -->
            <div style="background: #f5f5f5; padding: 15px; border-left: 4px solid #11998e; border-radius: 4px; margin: 20px 0;">
                <p style="margin: 0 0 8px 0; font-weight: 600; color: #11998e;">
                    {{ comment.get_user_name }} replied:
                </p>
                <p style="margin: 0; color: #555; white-space: pre-wrap;">{{ comment.content }}</p>
            </div>
            
            <!-- Button -->
            <div style="text-align: center; margin: 30px 0 20px 0;">
                <a href="{{ protocol }}://{{ domain }}/comments/{{ comment.pk }}/" 
                   style="display: inline-block; background: #11998e; color: #ffffff; padding: 12px 30px; text-decoration: none; border-radius: 5px; font-weight: 600; box-shadow: 0 2px 4px rgba(17, 153, 142, 0.4);">
                    View Reply
                </a>
            </div>
            
            <!-- Reply Details -->
            <div style="margin-top: 25px; padding-top: 20px; border-top: 1px solid #e0e0e0; font-size: 13px; color: #777;">
                <p style="margin: 5px 0;">
                    <strong>Replied:</strong> {{ comment.created_at|date:"F d, Y \a\t g:i A" }}
                </p>
            </div>
        </div>
        
        <!-- Footer -->
        <div style="background: #f8f9fa; padding: 20px; text-align: center; border-top: 1px solid #e0e0e0;">
            <p style="margin: 0; font-size: 12px; color: #888;">
                You're receiving this because someone replied to your comment.
            </p>
            <p style="margin: 10px 0 0 0; font-size: 12px; color: #888;">
                © {{ site_name }} - All rights reserved
            </p>
        </div>
    </div>
</body>
</html>