"""
Django Reusable Comments
========================

A professional-grade, reusable Django app for adding comment functionality to any model.
"""

__version__ = '1.0.0'

default_app_config = 'django_comments.apps.DjangoCommentsConfig'


